@@ -7,8 +7,8 @@ stuff, or (in the common case) a buffer and cursor. (Buffers are a 0-indexed
 list of lines implementing the Vim Python interface; cursors are a 2-tuple of
 integers for the 1-indexed row and column.)
 """
-from collections import namedtuple
 import time
+import os
 import re
 import subprocess
 
@@ -64,9 +64,9 @@ class LineProperties(object):
         """
         Returns True if the line is a diffscuss header line.
 
-        >>> LineProperties('%* This is a header line').is_diffscuss
+        >>> LineProperties('%* This is a header line').is_header
         True
-        >>> LineProperties('%- This is a body line').is_diffscuss
+        >>> LineProperties('%- This is a body line').is_header
         False
         """
         return self.line.startswith('%*')
@@ -76,9 +76,9 @@ class LineProperties(object):
         """
         Returns True if the line is a diffscuss body line.
 
-        >>> LineProperties('%* This is a header line').is_diffscuss
+        >>> LineProperties('%* This is a header line').is_body
         False
-        >>> LineProperties('%- This is a body line').is_diffscuss
+        >>> LineProperties('%- This is a body line').is_body
         True
         """
         return self.line.startswith('%-')
@@ -286,27 +286,18 @@ def insert_contextual_comment(buf, (row, col)):
 
 ### Showing source
 
-def _get_script(name):
-    """
-    Returns the path to the script named `name` relative to the diffscuss
-    installation directory.
-    """
-    return os.path.join(config()['diffscuss_dir'], name)
-
-
 def show_local_source(buf, (row, col)):
     """
     Returns the line number and path of the file corresponding to the change
     under the cursor.
     """
     cmd = """
-        {python} {script} -i {buffer_name} {row}
-        """.format(python=_get_python(),
-                   script=_get_script('find-local-source.py'),
+        {diffscuss} find-local -i {buffer_name} {row}
+        """.format(diffscuss=_get_script(),
                    buffer_name=buf.name, row=row)
     output = _get_output(cmd)
     filename, line = output.rsplit(' ', 1)
-    return  '+%s %s' % (line, filename)
+    return '+%s %s' % (line, filename)
 
 
 def show_old_source(buf, (row, col), tempfile):
@@ -322,6 +313,7 @@ def show_old_source(buf, (row, col), tempfile):
         'index_pattern': '^index ([a-f0-9]+)'
     })
 
+
 def show_new_source(buf, (row, col), tempfile):
     """
     Writes the new version of the file to the path given by `tempfile`, and
@@ -404,23 +396,14 @@ def show_source(buf, (row, col), tempfile, conf):
     return lineno
 
 
-### Mailboxes
+### Shelling out
 
-def _get_python():
+def _get_script():
     """
-    Returns the Python executable from the plugin config, or a reasonable
-    default.
+    Returns the path to the diffscuss CLI executable, relative to the
+    installation directory.
     """
-    return config().get('python', 'python')
-
-
-def _get_mailbox_script(name):
-    """
-    Returns the path to the script named `name` relative to the diffscuss
-    mailbox script directory.
-    """
-    mailbox_script_dir = os.path.join(config()['diffscuss_dir'], 'diffscuss-mb')
-    return os.path.join(mailbox_script_dir, name)
+    return os.path.join(config()['diffscuss_dir'], 'bin', 'diffscuss')
 
 
 def _get_output(command):
@@ -438,15 +421,16 @@ def _get_output(command):
     return output
 
 
+### Mailboxes
+
 def mailbox_check(_buffer, _cursor, tempfile):
     """
     Writes the output of the mailbox check script to `tempfile` for preview
     display.
     """
     cmd = """
-        {python} {script} > {tempfile}
-        """.format(python=_get_python(),
-                   script=_get_mailbox_script('dmb-check.py'),
+        {diffscuss} mailbox check > {tempfile}
+        """.format(diffscuss=_get_script(),
                    tempfile=tempfile)
     _get_output(cmd)
 
@@ -458,9 +442,8 @@ def mailbox_post(buffer_name, prompt_func):
     """
     recips = prompt_func('Post to: ')
     cmd = """
-        {python} {script} -p {diffscuss_file} {recips}
-        """.format(python=_get_python(),
-                   script=_get_mailbox_script('dmb-post.py'),
+        {diffscuss} mailbox post -p {diffscuss_file} {recips}
+        """.format(diffscuss=_get_script(),
                    diffscuss_file=buffer_name,
                    recips=recips)
     result = _get_output(cmd)
@@ -474,11 +457,10 @@ def mailbox_bounce(buffer_name, prompt_func):
     """
     recips = prompt_func('Bounce to: ')
     cmd = """
-        {python} {script} -p {diffscuss_file} {recips}
-        """.format(python=_get_python(),
-                   script=_get_mailbox_script('dmb-bounce.py'),
+        {diffscuss} mailbox bounce -p {diffscuss_file} {recips}
+        """.format(diffscuss=_get_script(),
                    diffscuss_file=buffer_name,
-                   recips=input_str)
+                   recips=recips)
     result = _get_output(cmd)
     return 'Bounced %s' % result
 
@@ -488,9 +470,8 @@ def mailbox_done(buffer_name, _prompt_func):
     Calls the mailbox done script.
     """
     cmd = """
-        {python} {script} -p {diffscuss_file}
-        """.format(python=_get_python(),
-                   script=_get_mailbox_script('dmb-done.py'),
+        {diffscuss} mailbox done -p {diffscuss_file}
+        """.format(diffscuss=_get_script(),
                    diffscuss_file=buffer_name)
     result = _get_output(cmd)
     return 'Completed %s' % result
